@@ -728,7 +728,7 @@ class CLASSIX:
     
     def explain(self, index1="NULL", index2="NULL", showsplist=True, max_colwidth=None, replace_name=None, 
                 plot=False, figsize=(10, 6), figstyle="ggplot", savefig=False, ind_color="k", ind_marker_size=150,
-                bbox={'facecolor': 'tomato', 'alpha': 0.2, 'pad': 2},
+                st_fcolor='tomato',  st_alpha=0.2, st_pad=2, bbox=None,
                 color='red', alpha=0.5, cline_width=0.5, figname=None, fmt='pdf'):
         """
         'self.explain(object/index) # prints an explanation for why a point object1 is in its cluster (or an outlier)
@@ -822,6 +822,12 @@ class CLASSIX:
         #     spdisplay = pd.DataFrame(self.splist[:, 1:], columns=cols)
         
         # -----------------------------second method--------------------------------
+        if bbox is None:
+            bbox = dict()
+            bbox['facecolor'] = st_fcolor
+            bbox['alpha'] = st_alpha
+            bbox['pad'] = st_pad
+            # {'facecolor': 'tomato', 'alpha': 0.2, 'pad': 2},
         if self.cluster_color is None:
             self.cluster_color = dict()
             for i in np.unique(self.labels_):
